module constants
!
! ==================================================================
!
! This module defines constants used throughout the package.
!
!
! Contact: blazej.bucha@stuba.sk
!
! ==================================================================


    use vartypes

    implicit none


    ! Constants for double precision computations
    ! --------------------------------------------------------------------------
    real(dp), parameter :: pi_dp = 3.14159265358979324_dp ! Constant "pi" in
                                                          ! double precision
    real(dp), parameter :: eps_dp = epsilon(1.0_dp) ! Machine epsilon for
                                                    ! the "dp" variable type
    integer,  parameter :: ind_dp = 960 ! Parameter to compute Legendre
                                        ! functions using the extended-range
                                        ! arithmetic in double precision
    real(dp), parameter :: root3_dp = 1.73205080756887729_dp ! "sqrt(3)" in
                                                             ! double precision
    ! --------------------------------------------------------------------------


    ! Constants for quadruple precision computations
    ! --------------------------------------------------------------------------
    ! Constant "pi" in quadruple precision
    real(qp), parameter :: pi_qp = 3.1415926535897932384626433832795028842_qp

    real(qp), parameter :: eps_qp = epsilon(1.0_qp) ! Machine epsilon for
                                                    ! the "qp" variable type
    integer,  parameter :: ind_qp = 16000 ! Parameter to compute Legendre
                                          ! functions using the extended-range
                                          ! arithmetic in quadruple precision
    ! "sqrt(3)" in quadruple precision
    real(qp), parameter :: root3_qp = &
                                   1.7320508075688772935274463415058723669428_qp
    ! --------------------------------------------------------------------------

end module constants
